@@ -6,9 +6,9 @@
 
 __all__ = ['NetcatsTool']
 
-
 import unittest
 import doctest
+import sys
 import os
 import socket
 import fcntl
@@ -20,6 +20,18 @@ from xnet.tools import Tool
 from xnet.net.ipv4 import IPRangeIterator
 
 
+def _get_output_filepath(item, base):
+    #
+    # item is the result of some specific processing
+    # and may contain arbitrary meta characters
+    # which should not affect the file system path
+    # where the output file is created.
+    #
+    item = item.replace('/', '__')
+    item = item.replace('\\', '--')
+    path = base + item
+    return path
+
 class NetcatsTool(Tool):
     '''
         NetcatsTool
@@ -42,20 +54,21 @@ class NetcatsTool(Tool):
         #    dict(dest='open')),
     ]
 
-    def __init__(self, options, stdin_data='', *args, **kw):
+    def __init__(self, options, outfile=sys.stdout, *args, **kw):
         super(NetcatsTool, self).__init__(options, *args, **kw)
-        self._stdin_queue = []
+        self._outfile = outfile
         self._stdin_pipe = self._nonblocking_pipe()
         self._addr = None
         self._port = 80
         if not self.options.port is None:
             self._port = int(self.options.port)
-        self._send_buffer = stdin_data
         self._recv_buffer = ''
 
     def __del__(self):
         os.close(self._stdin_pipe[0])
         os.close(self._stdin_pipe[1])
+        #if not self._outfile in (sys.stdout, sys.stderr):
+        #    self._outfile.close()
 
     def _nonblocking_pipe(self):
         pipe = os.pipe()
@@ -76,7 +89,7 @@ class NetcatsTool(Tool):
                     yield str(ip)
 
     def __parse__(self, item, iterator):
-        host = item.strip()
+        host = self._host = item.strip()
         addr = (host, self._port)
         self._addr = addr  # for __timeout__()
         result = {'addr': addr}
@@ -108,6 +121,13 @@ class NetcatsTool(Tool):
         #except gevent.GreenletExit:
         #    state = 'filtered'
 
+        outfile = sys.stdout
+        if self.options.split_output:
+            path = _get_output_filepath(self._host, self.options.split_output)
+            outfile = open(path, 'wb')
+            fcntl.fcntl(outfile.fileno(), fcntl.F_SETFL, os.O_NONBLOCK)
+        self._outfile = outfile
+
         done = False
         stdin = self._stdin_pipe[0]
         while not done and not sock is None:
@@ -122,7 +142,13 @@ class NetcatsTool(Tool):
             if sock in rlist:
                 data = sock.recv(4096)
                 if len(data) > 0:
-                    print 'sock:', data
+                    self._outfile.write(data)
+                    self._outfile.flush()
+                    if self.options.split_tee:
+                        sys.stdout.write(data)
+                        sys.stdout.flush()
+                    #sys.stdout.write(data)
+                    #sys.stdout.flush()
                 else:
                     done = True
 
@@ -133,46 +159,6 @@ class NetcatsTool(Tool):
                     sock.send(data)
                 else:
                     done = True
-
-        if 0 and not sock is None:
-            done = False
-            while not done:
-                while len(self._stdin_queue):
-                    data = self._stdin_queue[0]
-                    if len(data) > 0:
-                        sock.send(data)
-                    else:
-                        done = True
-                    del self._stdin_queue[0]
-                try:
-                    data = sock.recv(1024)
-                    if len(data) > 0:
-                        self._recv_buffer += data
-                    else:
-                        done = True
-                except socket.error, e:
-                    socket_error = 'FIXME2-' + errmsg.replace(' ', '-')
-                    sys.stderr.write(socket_error + '\n')
-                    done = True
-
-        if 0:
-            if not sock is None:
-                sock.send(self._send_buffer)
-                done = False
-                while not done:
-                    print 'poop loop'
-                    import sys
-                    sys.stdout.flush()
-                    try:
-                        data = sock.recv(1024)
-                        if len(data):
-                            self._recv_buffer += data
-                        else:
-                            done = True
-                    except socket.error, e:
-                        socket_error = 'FIXME2-' + errmsg.replace(' ', '-')
-                        sys.stderr.write(socket_error + '\n')
-                        done = True
         result['host'] = self._addr[0]
         result['port'] = self._addr[1]
         result['received'] = self._recv_buffer
@@ -181,7 +167,7 @@ class NetcatsTool(Tool):
 
     def __format__(self, line, parse_result, action_result):
         output = ''
-        if action_result:
+        if action_result and self.options.verbose:
             output = '{0} {1} {2}'.format(
                 action_result['host'],
                 action_result['port'],
@@ -195,9 +181,6 @@ class NetcatsTool(Tool):
             return 'timeout {0} {1}\n'.format(host, port)
         return None
 
-    def feed_stdin(self, data):
-        self._stdin_queue.append(data)
-
 
 
 def main():
