@@ -109,7 +109,7 @@ class ResolvTool(Tool):
         return output
 
     def __timeout__(self):
-        output = 'timeout {0}'.format(self._item)
+        output = 'timeout {0}\n'.format(self._item)
 
     @classmethod
     def __format_help__(cls):
