@@ -162,14 +162,14 @@ def _get_output_filepath(a, base):
     path = base + item
     return path
 
-def run(ToolImplementation, stdin_data_arg=None, tool_reads_stdin=False):
+def run(ToolImplementation, tool_reads_stdin=False):
     try:
-        return _run(ToolImplementation, stdin_data_arg, tool_reads_stdin)
+        return _run(ToolImplementation, tool_reads_stdin)
     except KeyboardInterrupt:
         return 1
     
 
-def _run(ToolImplementation, stdin_data_arg, tool_reads_stdin):
+def _run(ToolImplementation, tool_reads_stdin):
     '''
             tool_reads_stdin - tool uses stdin for other purpose than
                                to obtain startup arguments
@@ -195,12 +195,10 @@ def _run(ToolImplementation, stdin_data_arg, tool_reads_stdin):
     #
     # chain input sources, handle options
     # precedence order: cmdline, -r, stdin
-    # NOTE that if stdin_data_arg is not None,
-    # stdin is not used as a source for items.
     #
     _inputs = []
     if '-' in cmdlineinputs:
-        if not stdin_data_arg is None and not tool_reads_stdin:
+        if tool_reads_stdin:
             raise Exception(_E_INVALID_ARGUMENT_STDIN)
         cmdlineinputs.remove('-')
         _inputs.append(sys.stdin)
@@ -255,11 +253,9 @@ def _run(ToolImplementation, stdin_data_arg, tool_reads_stdin):
     inputchain = ToolImplementation.__massage__(inputchain)
 
     kwargs = {}
-    if not stdin_data_arg is None:
-        kwargs[stdin_data_arg] = sys.stdin.read()
 
     if tool_reads_stdin:
-        pool.spawn(stdin_disperser_greenlet, pool)
+        gevent.spawn(stdin_disperser_greenlet, pool)
 
 
     _t = 0.0
