@@ -128,7 +128,9 @@ class SSLInfoTool(Tool):
     def __format__(self, line, parse_result, action_result):
         output = ''
         host, port = parse_result['addr']
-        cd = action_result['components_dict']
+        x509 = action_result['x509']
+        cd = dict(x509.get_subject().get_components())
+        #cd = action_result['components_dict']
         if self.options.cn:
             output = '{0} {1}'.format(host, cd.get('CN', None))
         else:
