@@ -37,6 +37,13 @@ class TcpStateTool(Tool):
             dict(dest='open')),
     ]
 
+    def __repr__(self):
+        state = ('x', 'finished')[self.finished]
+        if hasattr(self, '_addr'):
+            host, port = self._addr
+            return '<tcpstate {0}:{1} {2}>'.format(host, port, state)
+        return '<tcpstate {0}>'.format(state)
+
     @classmethod
     def __massage__(self, iterator):
         for item in iterator:
