@@ -38,12 +38,16 @@ class WebgetTool(Tool):
             dict(dest='code', action='store_true')),
     ]
 
+    def __init__(self, *args, **kw):
+        super(WebgetTool, self).__init__(*args, **kw)
+        self._url = None
+
     def __parse__(self, line, iterator):
         '''
             only accepts plain urls atm.
         '''
         result = {}
-        url = line.strip()
+        self._url = url = line.strip()
         if not '://' in url:
             proto = 'http'
             if self.options.https:
@@ -107,13 +111,16 @@ class WebgetTool(Tool):
             if read_response:
                 _body = e.read()
         except urllib2.URLError, e:
-            _response = None
-            _code = '-'
-            _msg = 'URLError:' + str(e)
-            _body = None
-        except:
-            e = sys.exc_info()
-            self.set_error(e)
+            errmsg = _url + ' '
+            errmsg += e.reason.strerror.replace(' ', '-').replace(',', '-')
+            self.set_error(errmsg)
+            self.stderr = True
+            return None
+        #except:
+        #    e = str(sys.exc_info())
+        #    self.set_error(e)
+        #    self.stderr = True
+        #    return None
         finally:
             try:
                 _response.close()
@@ -162,6 +169,9 @@ Default format depend on commandline arguments.
         ''' % cls.__toolname__
         return output
 
+    def __timeout__(self):
+        return 'timeout {0}\n'.format(self._url)
+
 
 def main():
     import xnet.tools
